<?php

namespace App\Http\Controllers;

use App\Audio;
use App\AudioLanguage;
use App\Genre;
use App\Audiogenre;
use App\Menu;
use App\WorldCupPlayer;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Intervention\Image\Facades\Image;

class WorldCupPlayerController extends Controller
{

    public function index(Request $request)
    {
        
        if($request->search != NULL){
            $players = DB::table('world_cup_players')->where('name', 'like','%' . $request->search . '%')->paginate(12);
        }else{
            $players = DB::table('world_cup_players')->paginate(12);
        }
        
        return view('admin.worldcupplayer.index', compact('players'));
    }

    public function create()
    {
     
        return view('admin.worldcupplayer.create');
    }

    public function destroy($id)
    {
        if(env('DEMO_LOCK') == 1){
            return back()->with('deleted','This action is disabled in the demo !');
        }
        $new = WorldCupPlayer::findOrFail($id);
        $new->delete();
        return back()->with('deleted', 'player has been deleted');

    }

    public function edit($id)
    {
        $player= WorldCupPlayer::findOrFail($id);
        $position_l =[
            '1' => "Scorer",
            '2' =>"Assist",
            '3' => "Keeper",
        ];
       
        return view('admin.worldcupplayer.edit', compact('player' ,'position_l'));

    }

    public function update(Request $request, $id){
        
        $request->validate(['name' => 'required' ,
         'team' =>'required',
         'rank' =>'required',
         'position' =>'required']);

        $player = WorldCupPlayer::findOrFail($id);

        $input = $request->all();

        $player->update($input);

        return redirect('/admin/worldcupplayer')->with('updated', 'player has been updated');
    }

    public function store(Request $request)
    {

        $request->validate(['name' => 'required' ,
         'team' =>'required',
         'rank' =>'required',
         'position' =>'required']);

        $input = $request->all();

        $player = WorldCupPlayer::create($input);

        return back()->with('added', 'player has been added');

    }

    public function showStats(){

        $scorers = WorldCupPlayer::where('position','=', 1)->orderBy('rank')->paginate(10);

        $assists = WorldCupPlayer::where('position','=', 2)->orderBy('rank')->paginate(10);

        $keepers = WorldCupPlayer::where('position','=', 3)->orderBy('rank')->paginate(10);

        return view('worldcupstats', compact('scorers' ,'assists','keepers'));
    }

}